summaryrefslogtreecommitdiffstats
path: root/unix/tclUnixInit.c
diff options
context:
space:
mode:
Diffstat (limited to 'unix/tclUnixInit.c')
-rw-r--r--unix/tclUnixInit.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/unix/tclUnixInit.c b/unix/tclUnixInit.c
index a0a2c30..98c37f5 100644
--- a/unix/tclUnixInit.c
+++ b/unix/tclUnixInit.c
@@ -988,7 +988,7 @@ TclpSetVariables(
*
* Results:
* The return value is the index in environ of an entry with the name
* "name", or TCL_IO_FAILURE if there is no such entry. The integer at *lengthPtr is
* filled in with the length of name (if a matching entry is found) or
* the length of the environ array (if no matching entry is found).
*
@@ -1007,7 +1007,7 @@ TclpFindVariable(
* entries in environ (for unsuccessful
* searches). */
{
- size_t i, result = TCL_IO_FAILURE;
+ size_t i, result = TCL_INDEX_NONE;
const char *env, *p1, *p2;
Tcl_DString envString;
@@ -988,7 +988,7 @@ TclpSetVariables(
* Results:
* The return value is the index in environ of an entry with the name
- * "name", or TCL_IO_FAILURE if there is no such entry. The integer at *lengthPtr is
+ * "name", or TCL_INDEX_NONE if there is no such entry. The integer at *lengthPtr is
* filled in with the length of name (if a matching entry is found) or
* the length of the environ array (if no matching entry is found).